.. _trojanzoo.datasets:

trojanzoo.datasets
==================================
These are the basic building block for graphs

.. contents:: trojanzoo.datasets
    :depth: 2
    :local:
    :backlinks: top

.. currentmodule:: trojanzoo.datasets


.. autosummary::
    :toctree: generated
    :nosignatures:
    :template: classtemplate.rst

Dataset
------------------
.. autosummary::
    :toctree: generated
    :nosignatures:
    :template: classtemplate.rst

    Dataset